package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.dto.ModuleInfoDTO;
import com.diagbot.dto.QuestionModuleInfoDTO;
import com.diagbot.entity.ModuleInfo;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.service.impl.ModuleInfoServiceImpl;
import com.diagbot.util.ListUtil;
import com.diagbot.vo.ModuleInfoVO;
import com.google.common.collect.Lists;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author dsYun
 * @Description: 问诊模板
 * @date 2024年11月1日
 */
@Component
public class ModuleInfoFacade extends ModuleInfoServiceImpl {

    /**
     * 获取问诊模板
     *
     * @return 获取问诊模板
     */
    public List<ModuleInfoDTO> getModuleInfo() {
        List<ModuleInfoDTO> retList = Lists.newLinkedList();

        QueryWrapper<ModuleInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("is_deleted", IsDeleteEnum.N.getKey());
        List<ModuleInfo> moduleInfoList = this.list(queryWrapper);

        if (ListUtil.isEmpty(moduleInfoList)) {
            return retList;
        }

        for (ModuleInfo moduleInfo : moduleInfoList) {
            ModuleInfoDTO data = new ModuleInfoDTO();
            data.setId(moduleInfo.getId());
            data.setName(moduleInfo.getName());
            retList.add(data);
        }
        return retList;
    }

    /**
     * 根据问诊id获取内容
     *
     * @return 根据问诊id获取内容演示
     */
    public Map<String, List<QuestionModuleInfoDTO>> getModuleById(ModuleInfoVO moduleInfoVO) {
        Map<String, List<QuestionModuleInfoDTO>> map = new HashMap<>();
        List<QuestionModuleInfoDTO> list1 = new ArrayList<>();
        List<QuestionModuleInfoDTO> list2 = new ArrayList<>();
        List<QuestionModuleInfoDTO> moduleById = this.getModuleByIds(moduleInfoVO);
        if (ListUtil.isEmpty(moduleById)) {
            return map;
        }
        for (QuestionModuleInfoDTO questionModuleInfoDTO : moduleById) {
            if (questionModuleInfoDTO.getModeId() == 1) {
                list1.add(questionModuleInfoDTO);
            }
            if (questionModuleInfoDTO.getModeId() == 2) {
                list2.add(questionModuleInfoDTO);
            }
        }
        map.put("咳嗽",list1);
        map.put("咳痰",list2);
        return map;
    }
}
