package com.diagbot.web;

import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.*;
import com.diagbot.facade.ModuleInfoFacade;
import com.diagbot.vo.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * @author dsYun
 * @Description: 问诊模板 前端控制器
 * @date 2024年11月1日
 */
@RestController
@RequestMapping("/demo/moduleInfo")
@Api(value = "问诊模板API[by:dsYun]", tags = { "问诊模板API" })
@SuppressWarnings("unchecked")
public class ModuleInfoController {

    @Autowired
    private ModuleInfoFacade moduleInfoFacade;

    @ApiOperation(value = "获取问诊模板[by:dsYun]",
            notes = "")
    @PostMapping("/getModuleInfo")
    @SysLogger("getModuleInfo")
    @Transactional
    public RespDTO<List<ModuleInfoDTO>> getModuleInfo() {
        List<ModuleInfoDTO> res = moduleInfoFacade.getModuleInfo();
        return RespDTO.onSuc(res);
    }


    @ApiOperation(value = "根据问诊id获取内容[by:dsYun]",
            notes = "id: 请输入问诊id")
    @PostMapping("/getModuleById")
    @SysLogger("getModuleById")
    public RespDTO<Map<String,List<QuestionModuleInfoDTO>>> getModuleById(@Valid @RequestBody ModuleInfoVO moduleInfoVO) {
        Map<String,List<QuestionModuleInfoDTO>> data = moduleInfoFacade.getModuleById(moduleInfoVO);
        return RespDTO.onSuc(data);
    }
}
